Module error

Module error 

Structs

ErrorDetails
Detailed error information with optional source location.

Enums

Error
Error types for the Lemma system with source location tracking
ErrorKind
Classification of an Error. Serialized as the kind field on the flat object returned to JavaScript from WASM (engine/src/wasm.rs, JsError).
RequestErrorKind
Distinguishes HTTP 404 (not found) from 400 (bad request) for request errors.