pub fn commit_rational_to_decimal(
rational: &RationalInteger,
) -> Result<Decimal, NumericFailure>Expand description
Commit a rational to stored Decimal with a single division (finite precision).
pub fn commit_rational_to_decimal(
rational: &RationalInteger,
) -> Result<Decimal, NumericFailure>Commit a rational to stored Decimal with a single division (finite precision).