format_source

Function format_source 

pub fn format_source(source: &str, attribute: &str) -> Result<String, Error>
Parse a source string and format it to canonical Lemma source.

Returns an error if the source does not parse.