pub struct Expression {
pub kind: ExpressionKind,
pub source_location: Option<Source>,
}Expand description
An expression that can be evaluated, with source location
Expressions use semantic equality - two expressions with the same structure (kind) are equal regardless of source location. Hash is not implemented for AST Expression; use planning::semantics::Expression as map keys.
Fields
kind: ExpressionKindsource_location: Option<Source>Implementations
Sourceimpl Expression
impl Expression
Sourcepub fn new(kind: ExpressionKind, source_location: Source) -> Self
pub fn new(kind: ExpressionKind, source_location: Source) -> Self
Create a new expression with kind and source location