pub struct UnitFactor {
pub quantity_ref: String,
pub exp: i32,
}Expand description
A single factor in a compound unit expression.
quantity_ref is the name of the referenced unit (e.g. "meter", "second").
exp is the integer exponent, positive for numerator and negative for denominator.
For example meter/second^2 produces:
UnitFactor { quantity_ref: "meter", exp: 1 }UnitFactor { quantity_ref: "second", exp: -2 }
Fields
quantity_ref: Stringexp: i32Trait Implementations
Sourceimpl Clone for UnitFactor
impl Clone for UnitFactor
Sourcefn clone(&self) -> UnitFactor
fn clone(&self) -> UnitFactor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnitFactor
impl Debug for UnitFactor
Sourceimpl<'de> Deserialize<'de> for UnitFactor
impl<'de> Deserialize<'de> for UnitFactor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for UnitFactor
impl PartialEq for UnitFactor
Sourcefn eq(&self, other: &UnitFactor) -> bool
fn eq(&self, other: &UnitFactor) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for UnitFactor
impl Serialize for UnitFactor
impl Eq for UnitFactor
impl StructuralPartialEq for UnitFactor