pub enum SemanticConversionTarget {
Duration(SemanticDurationUnit),
ScaleUnit(String),
RatioUnit(String),
}Expand description
Target unit for conversion (semantic; used by evaluation/computation). Planning converts AST ConversionTarget into this so computation does not depend on parsing. Ratio vs scale is determined by looking up the unit in the type registry’s unit index.
Variants