pub enum TypeDefiningSpec {
Local,
Import {
spec: Arc<LemmaSpec>,
resolved_plan_hash: String,
},
}Expand description
Where the custom extension chain is rooted: same spec as this type, or imported from another resolved spec.
Variants
Local
Parent type is defined in the same spec as this type.
Import
Parent type was resolved from types loaded from this dependency (same concrete version as spec-reference facts).