pub enum TypeSpecification {
Boolean {
help: String,
default: Option<bool>,
},
Scale {
minimum: Option<Decimal>,
maximum: Option<Decimal>,
decimals: Option<u8>,
precision: Option<Decimal>,
units: ScaleUnits,
help: String,
default: Option<(Decimal, String)>,
},
Number {
minimum: Option<Decimal>,
maximum: Option<Decimal>,
decimals: Option<u8>,
precision: Option<Decimal>,
help: String,
default: Option<Decimal>,
},
Ratio {
minimum: Option<Decimal>,
maximum: Option<Decimal>,
decimals: Option<u8>,
units: RatioUnits,
help: String,
default: Option<Decimal>,
},
Text {
minimum: Option<usize>,
maximum: Option<usize>,
length: Option<usize>,
options: Vec<String>,
help: String,
default: Option<String>,
},
Date {
minimum: Option<DateTimeValue>,
maximum: Option<DateTimeValue>,
help: String,
default: Option<DateTimeValue>,
},
Time {
minimum: Option<TimeValue>,
maximum: Option<TimeValue>,
help: String,
default: Option<TimeValue>,
},
Duration {
help: String,
default: Option<(Decimal, DurationUnit)>,
},
Veto {
message: Option<String>,
},
Error,
}Variants
Boolean
Scale
Fields

units: ScaleUnitsNumber
Fields
Ratio
Fields

units: RatioUnitsText
Fields
Date
Time
Fields
Duration
Veto
Error
Sentinel type used during type inference to represent “type could not be determined.” This propagates through expressions without generating cascading errors. It must never appear in a successfully validated graph or execution plan.
Implementations
Sourceimpl TypeSpecification
impl TypeSpecification
pub fn boolean() -> Self
pub fn scale() -> Self
pub fn number() -> Self
pub fn ratio() -> Self
pub fn text() -> Self
pub fn date() -> Self
pub fn time() -> Self
pub fn duration() -> Self
pub fn veto() -> Self
pub fn apply_constraint( self, command: &str, args: &[CommandArg], ) -> Result<Self, String>