pub struct LiteralValue {
pub value: ValueKind,
pub lemma_type: LemmaType,
}Expand description
Literal value with type. The single value type in semantics.
Fields
value: ValueKindlemma_type: LemmaTypeImplementations
Sourceimpl LiteralValue
impl LiteralValue
pub fn text(s: String) -> Self
pub fn text_with_type(s: String, lemma_type: LemmaType) -> Self
pub fn number(n: Decimal) -> Self
pub fn number_with_type(n: Decimal, lemma_type: LemmaType) -> Self
pub fn scale_with_type(n: Decimal, unit: String, lemma_type: LemmaType) -> Self
Sourcepub fn number_interpreted_as_scale(value: Decimal, unit_name: String) -> Self
pub fn number_interpreted_as_scale(value: Decimal, unit_name: String) -> Self
Number interpreted as a scale value in the given unit (e.g. “3 in usd” where 3 is a number). Creates an anonymous one-unit scale type so computation does not depend on parsing types.
pub fn from_bool(b: bool) -> Self
pub fn date(dt: SemanticDateTime) -> Self
pub fn date_with_type(dt: SemanticDateTime, lemma_type: LemmaType) -> Self
pub fn time(t: SemanticTime) -> Self
pub fn time_with_type(t: SemanticTime, lemma_type: LemmaType) -> Self
pub fn duration(value: Decimal, unit: SemanticDurationUnit) -> Self
pub fn duration_with_type( value: Decimal, unit: SemanticDurationUnit, lemma_type: LemmaType, ) -> Self
pub fn ratio(r: Decimal, unit: Option<String>) -> Self
pub fn ratio_with_type( r: Decimal, unit: Option<String>, lemma_type: LemmaType, ) -> Self
Sourcepub fn display_value(&self) -> String
pub fn display_value(&self) -> String
Get a display string for this value (for UI/output)