LemmaBase

Struct LemmaBase 

pub struct LemmaBase { /* private fields */ }
The LemmaBase registry fetches Lemma source text from LemmaBase.com.

This is the default registry for the Lemma engine. It resolves @... identifiers by making HTTP GET requests to https://lemmabase.com/@{identifier}.lemma.

LemmaBase.com returns the requested spec with all of its dependencies inlined, so the resolution loop typically completes in a single iteration.

This struct is only available when the registry feature is enabled (which it is by default). Users who require strict sandboxing (no network access) can compile without this feature.

Implementations

Source

impl LemmaBase

pub const BASE_URL: &'static str = "https://lemmabase.com"

The base URL for the LemmaBase.com registry.

pub fn new() -> Self

Create a new LemmaBase registry backed by the real HTTP client (reqwest on native, fetch on WASM).