from_json

Function from_json 

pub fn from_json(json: &[u8]) -> Result<HashMap<String, Value>, Error>
Parse JSON object to data values for ExecutionPlan::set_data_values.

  • null values are skipped
  • JSON strings and numbers use convenience Lemma literal syntax
  • structured objects use the same serialization shape as evaluation output