pub fn from_msgpack(
_msgpack: &[u8],
_plan: &ExecutionPlan,
) -> Result<HashMap<String, String>, LemmaError>Expand description
Convert MsgPack values to string values for use with ExecutionPlan::with_values().
pub fn from_msgpack(
_msgpack: &[u8],
_plan: &ExecutionPlan,
) -> Result<HashMap<String, String>, LemmaError>Convert MsgPack values to string values for use with ExecutionPlan::with_values().