Structs
- Error
Details - Detailed error information with optional source location.
Enums
- Error
- Error types for the Lemma system with source location tracking
- Error
Kind - Classification of an
Error. Serialized as thekindfield on the flat object returned to JavaScript from WASM (engine/src/wasm.rs,JsError). - Request
Error Kind - Distinguishes HTTP 404 (not found) from 400 (bad request) for request errors.