Structs
- Resource
Limits - Limits to prevent abuse and enable predictable resource usage
Constants
Functions
- check_
max_ length - Validate that a name does not exceed the given character limit.
kindis a human-readable noun like “spec”, “fact”, “rule”, or “type”.