Module planning

Module planning 

Planning module for Lemma documents

This module performs complete static analysis and builds execution plans:

  • Builds Graph with facts and rules (validated, with types computed)
  • Builds ExecutionPlan from Graph (topologically sorted, ready for evaluation)
  • Validates document structure and references

Re-exports

pub use execution_plan::Branch;
pub use execution_plan::DocumentSchema;
pub use execution_plan::ExecutableRule;
pub use execution_plan::ExecutionPlan;
pub use semantics::ArithmeticComputation;
pub use semantics::ComparisonComputation;
pub use semantics::Expression;
pub use semantics::ExpressionKind;
pub use semantics::Fact;
pub use semantics::FactData;
pub use semantics::FactPath;
pub use semantics::FactValue;
pub use semantics::LemmaType;
pub use semantics::LiteralValue;
pub use semantics::LogicalComputation;
pub use semantics::MathematicalComputation;
pub use semantics::NegationType;
pub use semantics::PathSegment;
pub use semantics::RulePath;
pub use semantics::Source;
pub use semantics::Span;
pub use semantics::TypeExtends;
pub use semantics::ValueKind;
pub use semantics::VetoExpression;
pub use types::TypeRegistry;

Modules

execution_plan
Execution plan for evaluated documents
graph
semantics
Resolved semantic types for Lemma
types
Type registry for managing custom type definitions and resolution
validation
Semantic validation for Lemma documents

Functions

plan
Build execution plans for one or more Lemma documents.