pub struct TypeResolver { /* private fields */ }Expand description
Registry for managing and resolving custom types
Types are organized per spec (keyed by Arc
Implementations
Sourceimpl TypeResolver
impl TypeResolver
pub fn new() -> Self
Sourcepub fn register_all(&mut self, spec: &Arc<LemmaSpec>) -> Vec<Error>
pub fn register_all(&mut self, spec: &Arc<LemmaSpec>) -> Vec<Error>
Register all named types from a spec (skips inline types).
Sourcepub fn resolve(
&self,
all_specs: impl IntoIterator<Item = Arc<LemmaSpec>>,
) -> (HashMap<Arc<LemmaSpec>, ResolvedSpecTypes>, Vec<Error>)
pub fn resolve( &self, all_specs: impl IntoIterator<Item = Arc<LemmaSpec>>, ) -> (HashMap<Arc<LemmaSpec>, ResolvedSpecTypes>, Vec<Error>)
Resolve all named types for every spec and validate their specifications. Produces an entry for every spec (even those without named types) because every spec needs a unit_index containing at least the primitive ratio units.
Sourcepub fn register_type(
&mut self,
spec: &Arc<LemmaSpec>,
def: TypeDef,
) -> Result<(), Error>
pub fn register_type( &mut self, spec: &Arc<LemmaSpec>, def: TypeDef, ) -> Result<(), Error>
Register a user-defined type for a given spec (keyed by Arc
Sourcepub fn resolve_types(
&self,
spec: &Arc<LemmaSpec>,
) -> Result<ResolvedSpecTypes, Vec<Error>>
pub fn resolve_types( &self, spec: &Arc<LemmaSpec>, ) -> Result<ResolvedSpecTypes, Vec<Error>>
Resolve all types for a certain spec (keyed by Arc
Sourcepub fn resolve_named_types(
&self,
spec: &Arc<LemmaSpec>,
) -> Result<ResolvedSpecTypes, Vec<Error>>
pub fn resolve_named_types( &self, spec: &Arc<LemmaSpec>, ) -> Result<ResolvedSpecTypes, Vec<Error>>
Resolve only named types (for validation before inline type definitions are registered).
Sourcepub fn resolve_inline_types(
&self,
spec: &Arc<LemmaSpec>,
existing: ResolvedSpecTypes,
) -> Result<ResolvedSpecTypes, Vec<Error>>
pub fn resolve_inline_types( &self, spec: &Arc<LemmaSpec>, existing: ResolvedSpecTypes, ) -> Result<ResolvedSpecTypes, Vec<Error>>
Resolve only inline type definitions and merge them into an existing
ResolvedSpecTypes that already contains the named types.
Sourcepub fn resolve_primitive_type(&self, name: &str) -> Option<TypeSpecification>
pub fn resolve_primitive_type(&self, name: &str) -> Option<TypeSpecification>
Resolve a primitive type by name