pub struct LemmaBase { /* private fields */ }Expand description
The LemmaBase registry fetches Lemma source text from LemmaBase.
This is the default registry for the Lemma engine. It resolves @... identifiers
via GET {base}/{name}.lemma (name includes the leading @). The base depends on compile profile:
LemmaBase::BASE_URL (http://localhost:4222 in debug builds,
https://lemmabase.com in release builds).
LemmaBase.com returns the requested spec with all of its dependencies inlined, so the resolution loop typically completes in a single iteration.
This struct is only available when the registry feature is enabled (which it is
by default). Users who require strict sandboxing (no network access) can compile
without this feature.
Implementations
Sourceimpl LemmaBase
impl LemmaBase